#!/usr/bin/env python3
# coding: utf-8

# Import the libraries we need
import ThunderBorg
import time
import sys

# Start the Robot Core
TB = ThunderBorg.ThunderBorg()  # Create a new ThunderBorg object
#TB.i2cAddress = 0x15           # Uncomment and change the value if you have changed the board address
TB.Init()                       # Set the board up (checks the board is connected)
if not TB.foundChip:
    boards = ThunderBorg.ScanForThunderBorg()
    if len(boards) == 0:
        print('No ThunderBorg found, check you are attached :)')
    else:
        print('No ThunderBorg at address %02X, but we did find boards:' % (TB.i2cAddress))
        for board in boards:
            print('    %02X (%d)' % (board, board))
        print('If you need to change the I²C address change the setup line so it is correct, e.g.')
        print('TB.i2cAddress = 0x%02X' % (boards[0]))
    sys.exit()

# Display the existing limits
print()
battMin, battMax = TB.GetBatteryMonitoringLimits()
battCurrent = TB.GetBatteryReading()
print('Current battery monitoring settings:')
print('    Minimum  (red)     %02.2f V' % (battMin))
print('    Half-way (yellow)  %02.2f V' % ((battMin + battMax) / 2))
print('    Maximum  (green)   %02.2f V' % (battMax))
print
print('    Current voltage    %02.2f V' % (battCurrent))
print()

# Ask the user for new limits
print('To set to defaults use 0 for both limits')
battMin = float(input('New voltage for the minimum: '))
battMax = float(input('New voltage for the maximum: '))

# Check for reset
if battMin == battMax:
	print('Minimum and maximum match, setting to default limits')

# Set the new values
TB.SetBatteryMonitoringLimits(battMin, battMax)

# Display the new limits
print()
battMin, battMax = TB.GetBatteryMonitoringLimits()
battCurrent = TB.GetBatteryReading()
print('Current battery monitoring settings:')
print('    Minimum  (red)     %02.2f V' % (battMin))
print('    Half-way (yellow)  %02.2f V' % ((battMin + battMax) / 2))
print('    Maximum  (green)   %02.2f V' % (battMax))
print
print('    Current voltage    %02.2f V' % (battCurrent))
print()
